@@ -308,8 +308,18 @@ def complex_filter_calculator(smartquery, driver):
         logging.error(str(e))
 
 
-def smartner(nl, datasets, token, use_cache=None, cache_mode=None, similarity_threshold=None, model_version=None,
-             env="dev", language="en", response_type="deanonymize"):
+def smartner(nl, language="en", online=True, datasets=None, dataframe=None, response_type="deanonymize", token="",
+             use_ner=True, use_cache=False, use_redis=False, cache_mode="standard", model_version=None,
+             env="dev", similarity_threshold=0.85):
+    # Check mode online/offline
+    if online is True and not (nl != "" and datasets is not None and token != ""):
+        error = "!-!-! Online mode requires these inputs: natural language query, datasets IDs and authorization token."
+        print(error)
+        return []
+    elif online is False and not (nl != "" and dataframe is not None):
+        error = "!-!-! Offline mode requires these inputs: natural language query and dataframe."
+        print(error)
+        return []
 
     headers = {
         "Content-Type": "application/json",
@@ -326,42 +336,79 @@ def smartner(nl, datasets, token, use_cache=None, cache_mode=None, similarity_th
     else:
         url = url_list['BASE_URL_SMARTNER_PROD'] + "/query"
 
+    if dataframe is not None:
+        date_format = '%Y-%m-%d %H:%M:%S'
+        for c in dataframe.columns:
+            if "datetime" in str(dataframe[c].dtype):
+                dataframe[c] = dataframe[c].dt.strftime(date_format)
+    
+        dataframe = dataframe.to_dict()
+
     json_data = {
         "nl": nl,
         "lang": language,
-        "datasets": datasets
+        "datasets": datasets,
+        "dataframe": dataframe
     }
 
     # Params check
     params = {}
 
-    if use_cache in [True, False]:
-        params["use_cache"] = use_cache
-        if cache_mode in ["standard", "similarity", "only_cache"]:
-            params["cache_mode"] = cache_mode
+    if use_cache not in [True, False]:
+        use_cache = False
+        print("!-!-! Parameter use_cache not allowed. Setting to False.")
+    params["use_cache"] = use_cache
 
-    if type(similarity_threshold) == int or type(similarity_threshold) == float:
-        params["similarity_threshold"] = similarity_threshold
+    if cache_mode not in ["standard", "similarity", "only_cache"]:
+        cache_mode = "standard"
+        print("!-!-! Parameter similarity_threshold not allowed. Setting to 85%.")
+    params["cache_mode"] = cache_mode
 
-    if model_version is not None:
+    if not (type(similarity_threshold) == int or type(similarity_threshold) == float):
+        similarity_threshold = 0.85
+        print("!-!-! Parameter similarity_threshold not allowed. Setting to 85%.")
+    params["similarity_threshold"] = similarity_threshold
+
+    if model_version is None:
         params["model_version"] = model_version
 
-    if response_type in ["anonymize", "nl2query", "deanonymize", "query2sql"]:
-        params["response_type"] = response_type
+    if response_type not in ["anonymize", "nl2query", "deanonymize", "query2sql"]:
+        response_type = "deanonymize"
+        print("!-!-! Parameter response_type not allowed. Setting to deanonymize.")
+    params["response_type"] = response_type
+
+    if online not in [True, False]:
+        online = True
+        print("!-!-! Parameter online not allowed. Setting to True.")
+    params["online"] = online
+
+    if use_ner not in [True, False]:
+        use_ner = True
+        print("!-!-! Parameter use_ner not allowed. Setting to True.")
+    params["use_ner"] = use_ner
+
+    params["use_redis"] = False  # For now
 
     r = s.post(url=url, headers=headers, json=json_data, params=params)
     r.raise_for_status()
 
     try:
         response = r.json()
+
+        if not online:
+            df_response = []
+            for dt in response["results"]:
+                df_response.append(pd.DataFrame.from_dict(dt))
+            response["results"] = df_response
+            del df_response
+
         return response["results"]
     except Exception as e:
-        logging.error(str(e))
+        print(e)
         return []
 
 
 def smartner_automated_analysis(suggestions, token, env="dev", response_type="deanonymize"):
-
     headers = {
         "Content-Type": "application/json",
         "authorization": "Bearer " + token
